package system

import (
	"kpt-tmr-group/http/middleware"
	"kpt-tmr-group/pkg/apierr"
	"kpt-tmr-group/pkg/apiok"
	"kpt-tmr-group/pkg/valid"
	operationPb "kpt-tmr-group/proto/go/backend/operation"
	"net/http"

	"github.com/gin-gonic/gin"
)

func Auth(c *gin.Context) {
	var req operationPb.UserAuth
	if err := c.BindJSON(&req); err != nil {
		apierr.AbortBadRequest(c, http.StatusBadRequest, err)
		return
	}

	validate := func() error {
		return valid.ValidateStruct(&req,
			valid.Field(&req.UserName, valid.Required),
			valid.Field(&req.Password, valid.Required),
		)
	}

	if err := validate(); err != nil {
		apierr.AbortBadRequest(c, http.StatusBadRequest, err)
		return
	}

	res, err := middleware.Dependency(c).StoreEventHub.OpsService.Auth(c, &req)
	if err != nil {
		apierr.ClassifiedAbort(c, err)
		return
	}
	c.JSON(http.StatusOK, apiok.CommonResponse(res))
}

func AddUser(c *gin.Context) {

	req := make([]*operationPb.AddSystemUser, 0)
	if err := c.BindJSON(&req); err != nil {
		apierr.AbortBadRequest(c, http.StatusBadRequest, err)
		return
	}

	for _, field := range req {
		validate := func() error {
			return valid.ValidateStruct(&field,
				valid.Field(&field.Name, valid.Required),
				valid.Field(&field.Phone, valid.Required),
				valid.Field(&field.EmployeeName, valid.Required),
				valid.Field(&field.RoleId, valid.Required),
				valid.Field(&field.IsShow, valid.Max(2), valid.Min(0)),
			)
		}
		if err := validate(); err != nil {
			apierr.AbortBadRequest(c, http.StatusBadRequest, err)
			return
		}
	}

	err := middleware.Dependency(c).StoreEventHub.OpsService.CreateSystemUser(c, req)
	if err != nil {
		apierr.ClassifiedAbort(c, err)
		return
	}
	c.JSON(http.StatusOK, apiok.CommonResponse(apiok.NewApiOk(true)))
}

func GetUserInfo(c *gin.Context) {
	token := middleware.GetToken(c)
	if err := valid.Validate(token, valid.Required); err != nil {
		apierr.ClassifiedAbort(c, err)
		return
	}
	res, err := middleware.BackendOperation(c).OpsService.GetUserInfo(c, token)
	if err != nil {
		apierr.ClassifiedAbort(c, err)
		return
	}

	c.JSON(http.StatusOK, apiok.CommonResponse(res))
}
