package route

import (
	"kpt-tmr-group/http/handler"
	"kpt-tmr-group/http/handler/pasture"
	"kpt-tmr-group/http/handler/system"
	"kpt-tmr-group/http/middleware"

	"github.com/gin-gonic/gin"
)

func AppAPI(opts ...func(engine *gin.Engine)) func(s *gin.Engine) {
	return func(s *gin.Engine) {
		for _, opt := range opts {
			opt(s)
		}
		// Not Found
		s.NoRoute(handler.Handle404)
		// Health Check
		s.GET("/check", handler.Health)

		s.POST("/auth", system.Auth)

		// system API 组
		lingoRoute := authRouteGroup(s, "/api/v1/system/")
		lingoRoute.POST("/user_info", system.GetUserInfo)
		lingoRoute.POST("/user/add", system.AddUser)
		lingoRoute.POST("/user/list", system.AddUser)

		lingoRoute.POST("/role/add", system.AddRole)

		// 牧场管理
		lingoRoute.POST("/pasture/add", pasture.AddPasture)
		lingoRoute.POST("/pasture/list", pasture.SearchPastureList)
	}
}

func authRouteGroup(s *gin.Engine, relativePath string) *gin.RouterGroup {
	group := s.Group(relativePath)
	// 中间件鉴权
	group.Use(middleware.RequireAdmin(), middleware.Pagination(), middleware.CORS())
	return group
}
